@@ -1,9 +1,10 @@
 import os
 import textwrap
 
+from conan.tools.cmake.cmakedeps import FIND_MODE_NONE, FIND_MODE_CONFIG, FIND_MODE_MODULE, \
+    FIND_MODE_BOTH
 from conan.tools.cmake.cmakedeps.templates import CMakeDepsFileTemplate
-from conan.tools.cmake.utils import get_file_name
-
+from conan.tools.cmake.utils import get_cmake_package_name, get_find_mode
 """
 
 foo-release-x86_64-data.cmake
@@ -15,7 +16,7 @@ class ConfigDataTemplate(CMakeDepsFileTemplate):
 
     @property
     def filename(self):
-        data_fname = "" if not self.find_module_mode else "module-"
+        data_fname = "" if not self.generating_module else "module-"
         data_fname += "{}-{}".format(self.file_name, self.configuration.lower())
         if self.arch:
             data_fname += "-{}".format(self.arch)
@@ -41,8 +42,12 @@ class ConfigDataTemplate(CMakeDepsFileTemplate):
         # This is because in Conan 2.0 model, only the pure tools like CMake will be build_requires
         # for example a framework test won't be a build require but a "test/not public" require.
         dependency_filenames = self._get_dependency_filenames()
-        package_folder = self.conanfile.package_folder.replace('\\', '/')\
-                                                      .replace('$', '\\$').replace('"', '\\"')
+        # Get the nodes that have the property cmake_find_mode=None (no files to generate)
+        dependency_find_modes = self._get_dependencies_find_modes()
+        # package_folder might not be defined if Editable and layout()
+        package_folder = self.conanfile.package_folder or ""
+        package_folder = package_folder.replace('\\', '/').replace('$', '\\$').replace('"', '\\"')
+
         return {"global_cpp": global_cpp,
                 "pkg_name": self.pkg_name,
                 "file_name": self.file_name,
@@ -50,7 +55,8 @@ class ConfigDataTemplate(CMakeDepsFileTemplate):
                 "config_suffix": self.config_suffix,
                 "components_names": components_names,
                 "components_cpp": components_cpp,
-                "dependency_filenames": " ".join(dependency_filenames)}
+                "dependency_filenames": " ".join(dependency_filenames),
+                "dependency_find_modes": dependency_find_modes}
 
     @property
     def template(self):
@@ -59,10 +65,21 @@ class ConfigDataTemplate(CMakeDepsFileTemplate):
               ########### AGGREGATED COMPONENTS AND DEPENDENCIES FOR THE MULTI CONFIG #####################
               #############################################################################################
 
-              set({{ pkg_name }}_COMPONENT_NAMES {{ '${'+ pkg_name }}_COMPONENT_NAMES} {{ components_names }})
+              {% if components_names %}
+              list(APPEND {{ pkg_name }}_COMPONENT_NAMES {{ components_names }})
               list(REMOVE_DUPLICATES {{ pkg_name }}_COMPONENT_NAMES)
-              set({{ pkg_name }}_FIND_DEPENDENCY_NAMES {{ '${'+ pkg_name }}_FIND_DEPENDENCY_NAMES} {{ dependency_filenames }})
+              {% else %}
+              set({{ pkg_name }}_COMPONENT_NAMES "")
+              {% endif %}
+              {% if dependency_filenames %}
+              list(APPEND {{ pkg_name }}_FIND_DEPENDENCY_NAMES {{ dependency_filenames }})
               list(REMOVE_DUPLICATES {{ pkg_name }}_FIND_DEPENDENCY_NAMES)
+              {% else %}
+              set({{ pkg_name }}_FIND_DEPENDENCY_NAMES "")
+              {% endif %}
+              {% for dep_name, mode in dependency_find_modes.items() %}
+              set({{ dep_name }}_FIND_MODE "{{ mode }}")
+              {% endfor %}
 
               ########### VARIABLES #######################################################################
               #############################################################################################
@@ -117,18 +134,18 @@ class ConfigDataTemplate(CMakeDepsFileTemplate):
     def _get_global_cpp_cmake(self):
         global_cppinfo = self.conanfile.cpp_info.aggregated_components()
         pfolder_var_name = "{}_PACKAGE_FOLDER{}".format(self.pkg_name, self.config_suffix)
-        return _TargetDataContext(global_cppinfo, pfolder_var_name)
+        return _TargetDataContext(global_cppinfo, pfolder_var_name, self.conanfile.package_folder)
 
     def _get_required_components_cpp(self):
         """Returns a list of (component_name, DepsCppCMake)"""
         ret = []
         sorted_comps = self.conanfile.cpp_info.get_sorted_components()
-
+        pfolder_var_name = "{}_PACKAGE_FOLDER{}".format(self.pkg_name, self.config_suffix)
         direct_visible_host = self.conanfile.dependencies.filter({"build": False, "visible": True,
                                                                   "direct": True})
         for comp_name, comp in sorted_comps.items():
-            pfolder_var_name = "{}_PACKAGE_FOLDER{}".format(self.pkg_name, self.config_suffix)
-            deps_cpp_cmake = _TargetDataContext(comp, pfolder_var_name)
+            deps_cpp_cmake = _TargetDataContext(comp, pfolder_var_name,
+                                                self.conanfile.package_folder)
             public_comp_deps = []
             for require in comp.requires:
                 if "::" in require:  # Points to a component of a different package
@@ -153,16 +170,36 @@ class ConfigDataTemplate(CMakeDepsFileTemplate):
             for dep_name, _ in self.conanfile.cpp_info.required_components:
                 if dep_name and dep_name not in ret:  # External dep
                     req = direct_host[dep_name]
-                    ret.append(get_file_name(req, self.find_module_mode))
+                    ret.append(get_cmake_package_name(req))
         elif direct_host:
-            ret = [get_file_name(r, self.find_module_mode) for r in direct_host.values()]
+            ret = [get_cmake_package_name(r, self.generating_module) for r in direct_host.values()]
 
         return ret
 
+    def _get_dependencies_find_modes(self):
+        ret = {}
+        if self.conanfile.is_build_context:
+            return ret
+        deps = self.conanfile.dependencies.filter({"build": False, "visible": True, "direct": True})
+        for dep in deps.values():
+            dep_file_name = get_cmake_package_name(dep, self.generating_module)
+            find_mode = get_find_mode(dep)
+            default_value = "NO_MODULE" if not self.generating_module else "MODULE"
+            values = {
+                FIND_MODE_NONE: "",
+                FIND_MODE_CONFIG: "NO_MODULE",
+                FIND_MODE_MODULE: "MODULE",
+                # When the dependency is "both" or not defined, we use the one is forced
+                # by self.find_module_mode (creating modules files-> modules, config -> config)
+                FIND_MODE_BOTH: default_value,
+                None: default_value}
+            ret[dep_file_name] = values[find_mode]
+        return ret
+
 
 class _TargetDataContext(object):
 
-    def __init__(self, cpp_info, pfolder_var_name):
+    def __init__(self, cpp_info, pfolder_var_name, package_folder):
 
         def join_paths(paths):
             """
@@ -171,12 +208,20 @@ class _TargetDataContext(object):
             """
             ret = []
             for p in paths:
-                norm_path = p.replace('\\', '/').replace('$', '\\$').replace('"', '\\"')
-                if os.path.isabs(p):
-                    ret.append('"{}"'.format(norm_path))
-                else:
+                assert os.path.isabs(p), "{} is not absolute".format(p)
+
+                # Trying to use a ${mypkg_PACKAGE_FOLDER}/include path instead of full
+                # TODO: We could do something similar for some build_folder for editables
+                # package_folder can be None if editable and layout()
+                if package_folder is not None and p.startswith(package_folder):
                     # Prepend the {{ pkg_name }}_PACKAGE_FOLDER{{ config_suffix }}
-                    ret.append('"${%s}/%s"' % (pfolder_var_name, norm_path))
+                    rel = p[len(package_folder):]
+                    rel = rel.replace('\\', '/').replace('$', '\\$').replace('"', '\\"').lstrip("/")
+                    norm_path = ("${%s}/%s" % (pfolder_var_name, rel))
+                else:
+                    norm_path = p.replace('\\', '/').replace('$', '\\$').replace('"', '\\"')
+                ret.append('"{}"'.format(norm_path))
+
             return "\n\t\t\t".join(ret)
 
         def join_flags(separator, values):
@@ -199,7 +244,6 @@ class _TargetDataContext(object):
             return '"%s"' % ";".join(p.replace('\\', '/').replace('$', '\\$') for p in values)
 
         self.include_paths = join_paths(cpp_info.includedirs)
-        self.include_path = join_paths_single_var(cpp_info.includedirs)
         self.lib_paths = join_paths(cpp_info.libdirs)
         self.res_paths = join_paths(cpp_info.resdirs)
         self.bin_paths = join_paths(cpp_info.bindirs)
