@@ -328,9 +328,10 @@ class CppInfo(_CppInfo):
     def get_name(self, generator, default_name=True):
         name = super(CppInfo, self).get_name(generator, default_name=default_name)
 
-        # Legacy logic for pkg_config generator
+        # Legacy logic for pkg_config generator, do not enter this logic if the properties model
+        # is used: https://github.com/conan-io/conan/issues/10309
         from conans.client.generators.pkg_config import PkgConfigGenerator
-        if generator == PkgConfigGenerator.name:
+        if generator == PkgConfigGenerator.name and self.get_property("pkg_config_name") is None:
             fallback = self._name.lower() if self._name != self._ref_name else self._ref_name
             if PkgConfigGenerator.name not in self.names and self._name != self._name.lower():
                 conan_v2_error("Generated file and name for {gen} generator will change in"
@@ -607,8 +608,15 @@ class DepCppInfo(object):
                             del components[comp_name]
                             break
                     else:
+                        dset = set()
+                        for comp_name, comp in components.items():
+                            for dep_name, dep in components.items():
+                                for require in self._filter_component_requires(dep.requires):
+                                    if require == comp_name:
+                                        dset.add("   {} requires {}".format(dep_name, comp_name))
+                        dep_mesg = "\n".join(dset)
                         raise ConanException("There is a dependency loop in "
-                                             "'self.cpp_info.components' requires")
+                                "'self.cpp_info.components' requires:\n{}".format(dep_mesg))
                 self._sorted_components = ordered
             else:  # If components do not have requirements, keep them in the same order
                 self._sorted_components = self._cpp_info.components
