@@ -194,6 +194,10 @@ class OptionsValues(object):
             tokens = k.split(":")
             if len(tokens) == 2:
                 package, option = tokens
+                if package.endswith("/*"):
+                    # Compatibility with 2.0, only allowed /*, at Conan 2.0 a version or any
+                    # pattern would be allowed
+                    package = package[:-2]
                 package_values = self._reqs_options.setdefault(package.strip(),
                                                                PackageOptionValues())
                 package_values.add_option(option, v)
@@ -327,7 +331,8 @@ class PackageOption(object):
     def __init__(self, possible_values, name):
         self._name = name
         self._value = None
-        if possible_values == "ANY":
+        if possible_values == "ANY" or (isinstance(possible_values, list) and
+                                        "ANY" in possible_values):
             self._possible_values = "ANY"
         else:
             self._possible_values = sorted(str(v) for v in possible_values)
